@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,7 +35,6 @@ public:
 		       unsigned short new_count,
 		       const std::vector<FS> & FILESYSTEMS,
 		       bool only_unformatted,
-		       Sector cylinder_size,
 		       Glib::ustring disktype );
 	Partition Get_New_Partition( Byte_Value sector_size ) ;//overridden function
 
@@ -48,12 +47,10 @@ private:
 	Gtk::Entry entry;
 
 	std::vector<FS> FILESYSTEMS ;
-	int cylinder_size ;
 	
 	//signal handlers
 	void optionmenu_changed( bool );
 
-	Gdk::Color color_temp;
 	unsigned short new_count, first_creatable_fs ;
 };
 
