@@ -34,10 +34,15 @@ public:
 	FileSystem() ;
 	virtual ~FileSystem() {}
 
+	virtual const Glib::ustring get_custom_text( CUSTOM_TEXT ttype, int index = 0 ) ;
+	static const Glib::ustring get_generic_text( CUSTOM_TEXT ttype, int index = 0 ) ;
+
 	virtual FS get_filesystem_support() = 0 ;
 	virtual void set_used_sectors( Partition & partition ) = 0 ;
 	virtual void read_label( Partition & partition ) = 0 ;
 	virtual bool write_label( const Partition & partition, OperationDetail & operationdetail ) = 0 ;
+	virtual void read_uuid( Partition & partition ) = 0 ;
+	virtual bool write_uuid( const Partition & partition, OperationDetail & operationdetail ) = 0 ;
 	virtual bool create( const Partition & new_partition, OperationDetail & operationdetail ) = 0 ;
 	virtual bool resize( const Partition & partition_new,
 			     OperationDetail & operationdetail,
@@ -53,6 +58,11 @@ public:
 	
 protected:
 	int execute_command( const Glib::ustring & command, OperationDetail & operationdetail ) ;
+	int execute_command_timed( const Glib::ustring & command
+	                         , OperationDetail & operationdetail
+	                         , bool check_status = true ) ;
+	Glib::ustring mk_temp_dir( const Glib::ustring & infix, OperationDetail & operationdetail ) ;
+	void rm_temp_dir( const Glib::ustring dir_name, OperationDetail & operationdetail ) ;
 
 	//those are used in several places..
 	Glib::ustring output, error ;
