@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 #include "../include/Operation.h"
 
 #include <parted/parted.h>
+#ifdef HAVE_LIBPARTED_3_1_0_PLUS
+#include <parted/filesys.h>
+#endif
 #include <vector>
 #include <fstream>
 
@@ -32,6 +35,7 @@ namespace GParted
 class GParted_Core
 {
 public:
+	static Glib::Thread *mainthread;
 	GParted_Core() ;
 	~GParted_Core() ;
 
@@ -57,6 +61,7 @@ public:
 	Glib::ustring get_libparted_version() ;
 	Glib::ustring get_thread_status_message() ;
 
+	FileSystem * get_filesystem_object( const FILESYSTEM & filesystem ) ;
 private:
 	//detectionstuff..
 	void init_maps() ;
@@ -70,6 +75,7 @@ private:
 	void set_device_partitions( Device & device ) ;
 	GParted::FILESYSTEM get_filesystem() ; 
 	void read_label( Partition & partition ) ;
+	void read_uuid( Partition & partition ) ;
 	void insert_unallocated( const Glib::ustring & device_path,
 				 std::vector<Partition> & partitions,
 				 Sector start,
@@ -78,7 +84,7 @@ private:
 				 bool inside_extended ) ;
 	void set_mountpoints( std::vector<Partition> & partitions ) ;
 	void set_used_sectors( std::vector<Partition> & partitions ) ;
-#ifndef HAVE_LIBPARTED_3_0_0_PLUS
+#ifdef HAVE_LIBPARTED_FS_RESIZE
 	void LP_set_used_sectors( Partition & partition );
 #endif
 	void set_flags( Partition & partition ) ;
@@ -94,6 +100,8 @@ private:
 	
 	bool label_partition( const Partition & partition, OperationDetail & operation_detail ) ;
 	
+	bool change_uuid( const Partition & partition, OperationDetail & operation_detail ) ;
+
 	bool resize_move( const Device & device,
 			  const Partition & partition_old,
 			  Partition & partition_new,
@@ -105,7 +113,7 @@ private:
 	bool move_filesystem( const Partition & partition_old,
 			      const Partition & partition_new,
 			      OperationDetail & operationdetail ) ;
-#ifndef HAVE_LIBPARTED_3_0_0_PLUS
+#ifdef HAVE_LIBPARTED_FS_RESIZE
 	bool resize_move_filesystem_using_libparted( const Partition & partition_old,
 				      		     const Partition & partition_new,
 					      	     OperationDetail & operationdetail ) ;
@@ -197,6 +205,7 @@ private:
 	static PedExceptionOption ped_exception_handler( PedException * e ) ;
 
 	std::vector<FS> FILESYSTEMS ;
+	std::map< FILESYSTEM, FileSystem * > FILESYSTEM_MAP ;
 	FileSystem * p_filesystem ;
 	std::vector<PedPartitionFlag> flags;
 	Glib::ustring temp ;
