@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@
 #include <ctime>
 #include <vector>
 
+#define UUID_STRING_LENGTH 36
+
 namespace GParted
 {
 
@@ -46,6 +48,9 @@ const Byte_Value MEBIBYTE=(KIBIBYTE * KIBIBYTE);
 const Byte_Value GIBIBYTE=(MEBIBYTE * KIBIBYTE);
 const Byte_Value TEBIBYTE=(GIBIBYTE * KIBIBYTE);
 
+const Glib::ustring UUID_RANDOM = _("(New UUID - will be randomly generated)") ;
+const Glib::ustring UUID_RANDOM_NTFS_HALF = _("(Half new UUID - will be randomly generated)") ;
+
 enum FILESYSTEM
 {
 	FS_UNALLOCATED	= 0,
@@ -54,27 +59,28 @@ enum FILESYSTEM
 	FS_EXTENDED	= 3,
 
 	FS_BTRFS	= 4,
-	FS_EXT2		= 5,
-	FS_EXT3		= 6,
-	FS_EXT4		= 7,
-	FS_LINUX_SWAP	= 8,
+	FS_EXFAT	= 5, /* Also known as fat64 */
+	FS_EXT2		= 6,
+	FS_EXT3		= 7,
+	FS_EXT4		= 8,
 	FS_FAT16	= 9,
 	FS_FAT32	= 10,
-	FS_EXFAT	= 11, /* Also known as fat64 */
-	FS_NTFS		= 12,
-	FS_REISERFS	= 13,
-	FS_REISER4	= 14,
-	FS_XFS		= 15,
-	FS_JFS		= 16,
-	FS_HFS		= 17,
-	FS_HFSPLUS	= 18,
-	FS_UFS		= 19,
+	FS_HFS		= 11,
+	FS_HFSPLUS	= 12,
+	FS_JFS		= 13,
+	FS_LINUX_SWAP	= 14,
+	FS_LVM2_PV	= 15,
+	FS_NILFS2	= 16,
+	FS_NTFS		= 17,
+	FS_REISER4	= 18,
+	FS_REISERFS	= 19,
+	FS_UFS		= 20,
+	FS_XFS		= 21,
 
-	FS_USED		= 20,
-	FS_UNUSED	= 21,
+	FS_USED		= 22,
+	FS_UNUSED	= 23,
 
-	FS_LVM2		= 22,
-	FS_LUKS		= 23
+	FS_LUKS		= 24
 } ;
 
 enum SIZE_UNIT
@@ -88,6 +94,14 @@ enum SIZE_UNIT
 	UNIT_TIB	= 5
 } ;
 
+enum CUSTOM_TEXT
+{
+	CTEXT_NONE,
+	CTEXT_ACTIVATE_FILESYSTEM,		// Activate text ('Mount', 'Swapon', ...)
+	CTEXT_DEACTIVATE_FILESYSTEM,		// Deactivate text ('Unmount', 'Swapoff', ...)
+	CTEXT_CHANGE_UUID_WARNING,		// Warning to print when changing UUIDs
+} ;
+
 //struct to store file system information
 struct FS
 {
@@ -95,9 +109,7 @@ struct FS
 	{
 		NONE		= 0,
 		GPARTED		= 1,
-#ifndef HAVE_LIBPARTED_3_0_0_PLUS
 		LIBPARTED	= 2,
-#endif
 		EXTERNAL	= 3
 	};
 
@@ -105,6 +117,8 @@ struct FS
 	Support read ; //can we get the amount of used sectors?
 	Support read_label ;
 	Support write_label ;
+	Support read_uuid ;
+	Support write_uuid ;
 	Support create ;
 	Support grow ;
 	Support shrink ;
@@ -117,7 +131,7 @@ struct FS
 	
 	FS()
 	{
-		read = read_label = write_label = create = grow = shrink = move = check = copy = NONE;
+		read = read_label = write_label = read_uuid = write_uuid = create = grow = shrink = move = check = copy = NONE;
 		MIN = MAX = 0 ;
 	} 
 } ;
@@ -139,6 +153,8 @@ public:
 	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf( FILESYSTEM filesystem, int width, int height ) ;
 	static Glib::ustring get_filesystem_string( FILESYSTEM filesystem ) ;
 	static Glib::ustring get_filesystem_software( FILESYSTEM filesystem ) ;
+	static bool kernel_supports_fs( const Glib::ustring & fs ) ;
+	static bool kernel_version_at_least( int major_ver, int minor_ver, int patch_ver ) ;
 	static Glib::ustring format_size( Sector sectors, Byte_Value sector_size ) ;
 	static Glib::ustring format_time( std::time_t seconds ) ;
 	static double sector_to_unit( Sector sectors, Byte_Value sector_size, SIZE_UNIT size_unit ) ;
@@ -160,7 +176,14 @@ public:
 	static void tokenize( const Glib::ustring& str,
 	                      std::vector<Glib::ustring>& tokens,
 	                      const Glib::ustring& delimiters ) ;
+	static void split( const Glib::ustring& str,
+	                   std::vector<Glib::ustring>& result,
+	                   const Glib::ustring& delimiters     ) ;
 	static int convert_to_int(const Glib::ustring & src);
+	static Glib::ustring generate_uuid(void);
+
+private:
+	static bool get_kernel_version( int & major_ver, int & minor_ver, int & patch_ver ) ;
 };
 
 
