@@ -221,8 +221,9 @@ void Dialog_Progress::on_signal_show()
 			
 			while ( Gtk::Main::events_pending() )
 				Gtk::Main::iteration();
-
-			usleep( 10000 ) ;
+			gdk_threads_leave();
+			usleep( 100000 ) ;
+			gdk_threads_enter();
 		}
 
 		//set status (succes/error) for this operation
