@@ -39,6 +39,7 @@ void Partition::Reset()
 	messages .clear() ;
 	status = GParted::STAT_REAL ;
 	type = GParted::TYPE_UNALLOCATED ;
+	alignment = ALIGN_STRICT ;
 	filesystem = GParted::FS_UNALLOCATED ;
 	label .clear() ;
 	uuid .clear() ;
@@ -81,7 +82,7 @@ void Partition::Set(	const Glib::ustring & device_path,
 
 void Partition::Set_Unused( Sector sectors_unused )
 {
-	if ( sectors_unused < get_sector_length() )
+	if ( sectors_unused <= get_sector_length() )
 	{
 		this ->sectors_unused = sectors_unused ;
 		this ->sectors_used = ( sectors_unused == -1 ) ? -1 : get_sector_length() - sectors_unused ;
@@ -207,6 +208,14 @@ void Partition::sort_paths_and_remove_duplicates()
 	std::sort( paths .begin(), paths .end(), compare_paths ) ;
 }
 
+void Partition::add_mountpoint( const Glib::ustring & mountpoint, bool clear_mountpoints )
+{
+	if ( clear_mountpoints )
+		this ->mountpoints .clear() ;
+
+	this ->mountpoints .push_back( mountpoint ) ;
+}
+
 void Partition::add_mountpoints( const std::vector<Glib::ustring> & mountpoints, bool clear_mountpoints ) 
 {
 	if ( clear_mountpoints )
