@@ -19,9 +19,11 @@
 #include "../include/Utils.h"
 
 #include <sstream>
+#include <fstream>
 #include <iomanip>
 #include <glibmm/regex.h>
 #include <locale.h>
+#include <uuid/uuid.h>
 
 
 namespace GParted
@@ -63,7 +65,7 @@ Glib::ustring Utils::num_to_str( Sector number )
 	return ss .str() ;
 }
 
-//use http://developer.gnome.org/projects/gup/hig/2.0/design.html#Palette as a starting point..
+//use palette from http://developer.gnome.org/hig-book/2.32/design-color.html.en as a starting point.
 Glib::ustring Utils::get_color( FILESYSTEM filesystem )
 {
 	switch( filesystem )
@@ -80,6 +82,7 @@ Glib::ustring Utils::get_color( FILESYSTEM filesystem )
 		case FS_FAT16		: return "#00FF00" ;	//green
 		case FS_FAT32		: return "#18D918" ;	// ~ medium green
 		case FS_EXFAT		: return "#2E8B57" ;	// ~ sea green
+		case FS_NILFS2		: return "#826647" ;	//face skin dark
 		case FS_NTFS		: return "#42E5AC" ;	// ~ light turquoise
 		case FS_REISERFS	: return "#ADA7C8" ;	//purple hilight
 		case FS_REISER4		: return "#887FA3" ;	//purple medium
@@ -90,7 +93,7 @@ Glib::ustring Utils::get_color( FILESYSTEM filesystem )
 		case FS_UFS			: return "#D1940C" ;	//accent yellow dark
 		case FS_USED		: return "#F8F8BA" ;	// ~ light tan yellow
 		case FS_UNUSED		: return "#FFFFFF" ;	//white
-		case FS_LVM2		: return "#CC9966" ;	// ~ medium brown
+		case FS_LVM2_PV		: return "#CC9966" ;	// ~ medium brown
 		case FS_LUKS		: return "#625B81" ;	//purple dark
 
 		default				: return "#000000" ;
@@ -146,6 +149,7 @@ Glib::ustring Utils::get_filesystem_string( FILESYSTEM filesystem )
 		case FS_FAT16		: return "fat16" ;
 		case FS_FAT32		: return "fat32" ;
 		case FS_EXFAT		: return "exfat" ;
+		case FS_NILFS2		: return "nilfs2" ;
 		case FS_NTFS		: return "ntfs" ;
 		case FS_REISERFS	: return "reiserfs" ;
 		case FS_REISER4		: return "reiser4" ;
@@ -156,7 +160,7 @@ Glib::ustring Utils::get_filesystem_string( FILESYSTEM filesystem )
 		case FS_UFS		: return "ufs" ;
 		case FS_USED		: return _("used") ;
 		case FS_UNUSED		: return _("unused") ;
-		case FS_LVM2		: return "lvm2" ;
+		case FS_LVM2_PV		: return "lvm2 pv" ;
 		case FS_LUKS		: return "crypt-luks" ;
 
 		default			: return "" ;
@@ -177,7 +181,9 @@ Glib::ustring Utils::get_filesystem_software( FILESYSTEM filesystem )
 		case FS_HFSPLUS     : return "hfsprogs" ;
 		case FS_JFS         : return "jfsutils" ;
 		case FS_LINUX_SWAP  : return "util-linux" ;
-		case FS_NTFS        : return "ntfsprogs" ;
+		case FS_LVM2_PV     : return "lvm2" ;
+		case FS_NILFS2      : return "nilfs-utils" ;
+		case FS_NTFS        : return "ntfsprogs / ntfs-3g" ;
 		case FS_REISER4     : return "reiser4progs" ;
 		case FS_REISERFS    : return "reiserfsprogs" ;
 		case FS_UFS         : return "" ;
@@ -187,6 +193,61 @@ Glib::ustring Utils::get_filesystem_software( FILESYSTEM filesystem )
 	}
 }
 
+//Report whether or not the kernel supports a particular file system
+bool Utils::kernel_supports_fs( const Glib::ustring & fs )
+{
+	bool fs_supported = false ;
+
+	//Read /proc/filesystems and check for the file system name.
+	//  Will succeed for compiled in drivers and already loaded
+	//  moduler drivers.  If not found, try loading the driver
+	//  as a module and re-checking /proc/filesystems.
+	std::ifstream input ;
+	std::string line ;
+	input .open( "/proc/filesystems" ) ;
+	if ( input )
+	{
+		while ( input >> line )
+			if ( line == fs )
+			{
+				fs_supported = true ;
+				break ;
+			}
+		input .close() ;
+	}
+	if ( fs_supported )
+		return true ;
+
+	Glib::ustring output, error ;
+	execute_command( "modprobe " + fs, output, error, true ) ;
+
+	input .open( "/proc/filesystems" ) ;
+	if ( input )
+	{
+		while ( input >> line )
+			if ( line == fs )
+			{
+				fs_supported = true ;
+				break ;
+			}
+		input .close() ;
+	}
+
+	return fs_supported ;
+}
+
+//Report if kernel version is >= (major, minor, patch)
+bool Utils::kernel_version_at_least( int major_ver, int minor_ver, int patch_ver )
+{
+	int actual_major_ver, actual_minor_ver, actual_patch_ver ;
+	if ( ! get_kernel_version( actual_major_ver, actual_minor_ver, actual_patch_ver ) )
+		return false ;
+	bool result =    ( actual_major_ver > major_ver )
+	              || ( actual_major_ver == major_ver && actual_minor_ver > minor_ver )
+	              || ( actual_major_ver == major_ver && actual_minor_ver == minor_ver && actual_patch_ver >= patch_ver ) ;
+	return result ;
+}
+
 Glib::ustring Utils::format_size( Sector sectors, Byte_Value sector_size )
 {
 	std::stringstream ss ;
@@ -474,6 +535,9 @@ Glib::ustring Utils::get_lang()
 	return lang ;
 }
 
+//Extract a list of tokens from any number of background separator characters
+//  E.g., tokenize(str="  word1   word2   ", tokens, delimiters=" ")
+//        -> tokens=["word1","word2]
 //The tokenize method copied and adapted from:
 //  http://www.linuxselfhelp.com/HOWTO/C++Programming-HOWTO-7.html
 void Utils::tokenize( const Glib::ustring& str,
@@ -496,6 +560,30 @@ void Utils::tokenize( const Glib::ustring& str,
 	}
 }
 
+//Split string on every delimiter, appending to the vector.  Inspired by:
+//  http://stackoverflow.com/questions/236129/how-to-split-a-string-in-c/3616605#3616605
+//  E.g. using Utils::split(str, result, ":") for str -> result
+//  "" -> []   "a" -> ["a"]   "::" -> ["","",""]   ":a::bb" -> ["","a","","bb"]
+void Utils::split( const Glib::ustring& str,
+                   std::vector<Glib::ustring>& result,
+                   const Glib::ustring& delimiters     )
+{
+	//Special case zero length string to empty vector
+	if ( str == "" )
+		return ;
+	Glib::ustring::size_type fromPos  = 0 ;
+	Glib::ustring::size_type delimPos = str.find_first_of( delimiters );
+	while ( Glib::ustring::npos != delimPos )
+	{
+		Glib::ustring word( str, fromPos, delimPos - fromPos ) ;
+		result .push_back( word ) ;
+		fromPos = delimPos + 1 ;
+		delimPos = str.find_first_of( delimiters, fromPos ) ;
+	}
+	Glib::ustring word( str, fromPos ) ;
+	result. push_back( word ) ;
+}
+
 // Converts a Glib::ustring into a int
 int Utils::convert_to_int(const Glib::ustring & src)
 {
@@ -506,5 +594,50 @@ int Utils::convert_to_int(const Glib::ustring & src)
 	return ret_val;
 }
 
+// Create a new UUID
+Glib::ustring Utils::generate_uuid(void)
+{
+	uuid_t uuid;
+	char uuid_str[UUID_STRING_LENGTH+1];
+
+	uuid_generate(uuid);
+	uuid_unparse(uuid,uuid_str);
+
+	return uuid_str;
+}
+
+//private functions ...
+
+//Read kernel version, reporting success or failure
+bool Utils::get_kernel_version( int & major_ver, int & minor_ver, int & patch_ver )
+{
+	static bool read_file = false ;
+	static int read_major_ver = -1 ;
+	static int read_minor_ver = -1 ;
+	static int read_patch_ver = -1 ;
+
+	bool success = false ;
+	if ( ! read_file )
+	{
+		std::ifstream input( "/proc/version" ) ;
+		std::string line ;
+		if ( input )
+		{
+			getline( input, line ) ;
+			sscanf( line .c_str(), "Linux version %d.%d.%d",
+			        &read_major_ver, &read_minor_ver, &read_patch_ver ) ;
+			input .close() ;
+		}
+		read_file = true ;
+	}
+	if ( read_major_ver > -1 && read_minor_ver > -1 && read_patch_ver > -1 )
+	{
+		major_ver = read_major_ver ;
+		minor_ver = read_minor_ver ;
+		patch_ver = read_patch_ver ;
+		success = true ;
+	}
+	return success ;
+}
 
 } //GParted..
