@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 #include "../include/OperationDelete.h"
 #include "../include/OperationFormat.h"
 #include "../include/OperationResizeMove.h"
+#include "../include/OperationChangeUUID.h"
 #include "../include/OperationLabelPartition.h"
 #include "../config.h"
 
@@ -65,6 +66,7 @@ Win_GParted::Win_GParted( const std::vector<Glib::ustring> & user_devices )
         MENU_FLAGS =
         MENU_INFO =
         MENU_LABEL_PARTITION =
+        MENU_CHANGE_UUID =
         TOOLBAR_UNDO =
         TOOLBAR_APPLY = -1 ;
 
@@ -301,6 +303,7 @@ void Win_GParted::init_toolbar()
 void Win_GParted::init_partition_menu() 
 {
 	int index = 0 ;
+
 	//fill menu_partition
 	image = manage( new Gtk::Image( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ) );
 	menu_partition .items() .push_back( 
@@ -354,7 +357,8 @@ void Win_GParted::init_partition_menu()
 	index++ ;
 	
 	menu_partition .items() .push_back(
-			Gtk::Menu_Helpers::MenuElem( _("Unmount"),
+			//This is a placeholder text. It will be replaced with some other text before it is used
+			Gtk::Menu_Helpers::MenuElem( "--placeholder--",
 						     sigc::mem_fun( *this, &Win_GParted::toggle_swap_mount_state ) ) );
 	MENU_TOGGLE_MOUNT_SWAP = index++ ;
 		
@@ -381,6 +385,11 @@ void Win_GParted::init_partition_menu()
 						     sigc::mem_fun( *this, &Win_GParted::activate_label_partition ) ) );
 	MENU_LABEL_PARTITION = index++ ;
 
+	menu_partition .items() .push_back(
+			Gtk::Menu_Helpers::MenuElem( _("New UU_ID"),
+						     sigc::mem_fun( *this, &Win_GParted::activate_change_uuid ) ) );
+	MENU_CHANGE_UUID = index++ ;
+
 	menu_partition .items() .push_back( Gtk::Menu_Helpers::SeparatorElem() ) ;
 	index++ ;
 	
@@ -400,8 +409,8 @@ Gtk::Menu * Win_GParted::create_format_menu()
 	{
 		//Skip luks, lvm2, and unknown because these are not file systems
 		if (
-		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LUKS ||
-		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LVM2 ||
+		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LUKS    ||
+		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LVM2_PV ||
 		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_UNKNOWN
 		   )
 			continue ;
@@ -617,9 +626,9 @@ void Win_GParted::show_pulsebar( const Glib::ustring & status_message )
 		pulsebar .pulse();
 		while ( Gtk::Main::events_pending() )
 			Gtk::Main::iteration();
-		
-		usleep( 10000 );
-
+		gdk_threads_leave();
+		usleep( 100000 );
+		gdk_threads_enter();
 		Glib::ustring tmp_msg = gparted_core .get_thread_status_message() ;
 		if ( tmp_msg != "" )
 			statusbar .push( tmp_msg ) ;
@@ -674,10 +683,14 @@ void Win_GParted::Add_Operation( Operation * operation, int index )
 	if ( operation )
 	{ 
 		Glib::ustring error ;
+		//Add any of the listed operations without further checking, but
+		//  for the other operations (_CREATE, _RESIZE_MOVE and _COPY)
+		//  ensure the partition is correctly aligned.
 		//FIXME: this is becoming a mess.. maybe it's better to check if partition_new > 0
 		if ( operation ->type == OPERATION_DELETE ||
 		     operation ->type == OPERATION_FORMAT ||
 		     operation ->type == OPERATION_CHECK ||
+		     operation ->type == OPERATION_CHANGE_UUID ||
 		     operation ->type == OPERATION_LABEL_PARTITION ||
 		     gparted_core .snap_to_alignment( operation ->device, operation ->partition_new, error )
 		   )
@@ -753,6 +766,23 @@ bool Win_GParted::Merge_Operations( unsigned int first, unsigned int second )
 
 		return true;
 	}
+	// Two change-uuid change operations on the same partition
+	else if ( operations[ first ]->type == OPERATION_CHANGE_UUID &&
+	          operations[ second ]->type == OPERATION_CHANGE_UUID &&
+	          operations[ first ]->partition_new == operations[ second ]->partition_original
+	        )
+	{
+		// Changing half the UUID should not override changing all of it
+		if ( operations[ first ]->partition_new.uuid == UUID_RANDOM_NTFS_HALF ||
+		     operations[ second ]->partition_new.uuid == UUID_RANDOM )
+			operations[ first ]->partition_new.uuid = operations[ second ]->partition_new.uuid;
+		operations[ first ]->create_description() ;
+		remove_operation( second );
+
+		Refresh_Visual();
+
+		return true;
+	}
 	// Two check operations of the same partition
 	else if ( operations[ first ]->type == OPERATION_CHECK &&
 	          operations[ second ]->type == OPERATION_CHECK &&
@@ -879,10 +909,10 @@ void Win_GParted::set_valid_operations()
 	allow_new( false ); allow_delete( false ); allow_resize( false ); allow_copy( false );
 	allow_paste( false ); allow_format( false ); allow_toggle_swap_mount_state( false ) ;
 	allow_manage_flags( false ) ; allow_check( false ) ; allow_label_partition( false ) ;
-	allow_info( false ) ;
+	allow_change_uuid( false ); allow_info( false ) ;
 	
-       	dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() )
-		->set_label( _("_Unmount") ) ;
+	dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() )
+		->set_label( FileSystem::get_generic_text ( CTEXT_DEACTIVATE_FILESYSTEM ) ) ;
 
 	menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .show() ;
 	menu_partition .items()[ MENU_MOUNT ] .hide() ;	
@@ -898,33 +928,37 @@ void Win_GParted::set_valid_operations()
 	if ( selected_partition .type != GParted::TYPE_UNALLOCATED && selected_partition .status == GParted::STAT_REAL )
 		allow_manage_flags( true ) ; 
 
-	//deal with swap...
-	if ( selected_partition .filesystem == GParted::FS_LINUX_SWAP )
-	{
-		if ( selected_partition .status == GParted::STAT_REAL )
-			allow_toggle_swap_mount_state( true ) ;
+	//Activate / deactivate
+	if ( gparted_core .get_filesystem_object ( selected_partition .filesystem ) )
+		dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() )
+			->set_label( gparted_core .get_filesystem_object ( selected_partition .filesystem )
+			             ->get_custom_text (  selected_partition .busy
+			                                ? CTEXT_DEACTIVATE_FILESYSTEM
+			                                : CTEXT_ACTIVATE_FILESYSTEM
+			                               )
+			           ) ;
+	else
+		dynamic_cast<Gtk::Label*>( menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() )
+			->set_label( FileSystem::get_generic_text (  selected_partition .busy
+			                                           ? CTEXT_DEACTIVATE_FILESYSTEM
+			                                           : CTEXT_ACTIVATE_FILESYSTEM )
+			                                          ) ;
 
-		if ( selected_partition .busy )
-		{
-			dynamic_cast<Gtk::Label*>(menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() ) 
-				->set_label( _("_Swapoff") ) ;
-
-			return ;
-		}
-		else
-       			dynamic_cast<Gtk::Label*>(menu_partition .items()[ MENU_TOGGLE_MOUNT_SWAP ] .get_child() ) 
-				->set_label( _("_Swapon") ) ;
-	}
-
-	//only unmount is allowed (if ! extended)
-	if ( selected_partition .busy )	
-	{
-		if ( selected_partition .type != GParted::TYPE_EXTENDED )
-			allow_toggle_swap_mount_state( true ) ;
+	//Only permit mount/unmount, swapon/swapoff, ... if action is available
+	if (    selected_partition .status == GParted::STAT_REAL
+	     && selected_partition .type != GParted::TYPE_EXTENDED
+	     && selected_partition .filesystem != GParted::FS_LVM2_PV
+	     && (    selected_partition .busy
+	          || selected_partition .get_mountpoints() .size() /* Have mount point(s) */
+	          || selected_partition .filesystem == GParted::FS_LINUX_SWAP
+	        )
+	   )
+		allow_toggle_swap_mount_state( true ) ;
 
+	//only unmount/swapoff/... is allowed if busy
+	if ( selected_partition .busy )
 		return ;
-	}
-	
+
 	//UNALLOCATED
 	if ( selected_partition .type == GParted::TYPE_UNALLOCATED )
 	{
@@ -1017,10 +1051,16 @@ void Win_GParted::set_valid_operations()
 		if ( selected_partition .status == GParted::STAT_REAL && fs .write_label )
 			allow_label_partition( true ) ;
 
-		if ( selected_partition .get_mountpoints() .size() )
+		//only allow changing UUID of real partitions that support it
+		if ( selected_partition .status == GParted::STAT_REAL && fs .write_uuid )
+			allow_change_uuid( true ) ;
+
+		//Generate Mount on submenu, except for LVM2 PVs
+		//  borrowing mount point to display the VGNAME
+		if (   selected_partition .filesystem != GParted::FS_LVM2_PV
+		    && selected_partition .get_mountpoints() .size()
+		   )
 		{
-			allow_toggle_swap_mount_state( true ) ;
-			
 			menu = menu_partition .items()[ MENU_MOUNT ] .get_submenu() ;
 			menu ->items() .clear() ;
 			for ( unsigned int t = 0 ; t < selected_partition .get_mountpoints() .size() ; t++ )
@@ -1370,7 +1410,7 @@ void Win_GParted::menu_help_about()
 	dialog .set_logo_icon_name( "gparted" ) ;
 	dialog .set_version( VERSION ) ;
 	dialog .set_comments( _( "GNOME Partition Editor" ) ) ;
-	dialog .set_copyright( "Copyright © 2004-2006 Bart Hakvoort\nCopyright © 2008-2011 Curtis Gedak" ) ;
+	dialog .set_copyright( "Copyright © 2004-2006 Bart Hakvoort\nCopyright © 2008-2012 Curtis Gedak" ) ;
 
 	//authors
 	strings .push_back( "Bart Hakvoort <gparted@users.sf.net>" ) ;
@@ -1516,7 +1556,9 @@ void Win_GParted::activate_resize()
 			Add_Operation( operation ) ;
 
 			//Display notification if move operation has been queued
-			if ( operation ->partition_original .sector_start != operation ->partition_new .sector_start )
+			if (   operation ->partition_original .sector_start != operation ->partition_new .sector_start
+			    && operation ->partition_original .type != TYPE_EXTENDED
+			   )
 			{
 				//Warn that move operation might break boot process
 				Gtk::MessageDialog dialog( *this
@@ -1531,13 +1573,13 @@ void Win_GParted::activate_resize()
 					String::ucompose( _( "You have queued an operation to move the start sector of partition %1." )
 					                , operation ->partition_original .get_path()
 					                ) ;
-				tmp_msg += "  Failure to boot is most likely to occur if you move the GNU/Linux partition containing /boot, or if you move the Windows system partition C:." ;
+				tmp_msg += _( "  Failure to boot is most likely to occur if you move the GNU/Linux partition containing /boot, or if you move the Windows system partition C:." ) ;
 				tmp_msg += "\n" ;
 				tmp_msg += _( "You can learn how to repair the boot configuration in the GParted FAQ." ) ;
 				tmp_msg += "\n" ;
 				tmp_msg += "http://gparted.org/faq.php" ;
 				tmp_msg += "\n\n" ;
-				tmp_msg += "Moving a partition might take a very long time to apply." ;
+				tmp_msg += _( "Moving a partition might take a very long time to apply." ) ;
 				dialog .set_secondary_text( tmp_msg ) ;
 				dialog .run() ;
 			}
@@ -1594,8 +1636,10 @@ void Win_GParted::activate_paste()
 	else
 	{
 		Partition partition_new = selected_partition ;
+		partition_new .alignment = ALIGN_STRICT ;
 		partition_new .filesystem = copied_partition .filesystem ;
 		partition_new .label = copied_partition .label ;
+		partition_new .uuid = copied_partition .uuid ;
 		partition_new .color = copied_partition .color ;
 		partition_new .set_used( copied_partition .sectors_used ) ;
 		partition_new .messages .clear() ;
@@ -2295,19 +2339,7 @@ void Win_GParted::activate_label_partition()
 	{
 		dialog .hide() ;
 		//Make a duplicate of the selected partition (used in UNDO)
-		Partition part_temp ;
-		part_temp .Set( devices[ current_device ] .get_path(),
-				selected_partition .get_path(),
-				selected_partition .partition_number,
-				selected_partition .type,
-				selected_partition .filesystem,
-				selected_partition .sector_start,
-				selected_partition .sector_end,
-				devices[ current_device ] .sector_size,
-				selected_partition .inside_extended,
-				false ) ;
-		part_temp .Set_Unused( selected_partition.sectors_unused );
-		part_temp .set_used( selected_partition.sectors_used );
+		Partition part_temp = selected_partition ;
 
 		part_temp .label = dialog .get_new_label();
 
@@ -2329,6 +2361,55 @@ void Win_GParted::activate_label_partition()
 	}
 }
 	
+void Win_GParted::activate_change_uuid()
+{
+	if ( gparted_core .get_filesystem_object( selected_partition .filesystem ) ->get_custom_text ( CTEXT_CHANGE_UUID_WARNING ) != "" ) {
+		int i ;
+		Gtk::MessageDialog dialog( *this
+					 , gparted_core .get_filesystem_object( selected_partition .filesystem ) ->get_custom_text ( CTEXT_CHANGE_UUID_WARNING, 0 )
+					 , false
+					 , Gtk::MESSAGE_WARNING
+					 , Gtk::BUTTONS_OK
+					 , true
+					 ) ;
+		Glib::ustring tmp_msg = "" ;
+		for ( i = 1 ; gparted_core .get_filesystem_object( selected_partition .filesystem ) ->get_custom_text ( CTEXT_CHANGE_UUID_WARNING, i ) != "" ; i++ ) {
+			if ( i > 1 )
+				tmp_msg += "\n\n" ;
+			tmp_msg += gparted_core .get_filesystem_object( selected_partition .filesystem ) ->get_custom_text ( CTEXT_CHANGE_UUID_WARNING, i ) ;
+		}
+		dialog .set_secondary_text( tmp_msg ) ;
+		dialog .run() ;
+	}
+
+	//Make a duplicate of the selected partition (used in UNDO)
+	Partition part_temp = selected_partition ;
+
+	if ( part_temp .filesystem == GParted::FS_NTFS )
+		//Explicitly ask for half, so that the user will be aware of it
+		//Also, keep this kind of policy out of the NTFS code.
+		part_temp .uuid = UUID_RANDOM_NTFS_HALF ;
+	else
+		part_temp .uuid = UUID_RANDOM ;
+
+
+	Operation * operation = new OperationChangeUUID( devices[ current_device ],
+								selected_partition, part_temp ) ;
+	operation ->icon = render_icon( Gtk::Stock::EXECUTE, Gtk::ICON_SIZE_MENU );
+
+	Add_Operation( operation ) ;
+
+	// Verify if the two operations can be merged
+	for ( unsigned int t = 0 ; t < operations .size() - 1 ; t++ )
+	{
+		if ( operations[ t ] ->type == OPERATION_CHANGE_UUID )
+		{
+			if( Merge_Operations( t, operations .size() -1 ) )
+				break;
+		}
+	}
+}
+
 void Win_GParted::activate_undo()
 {
 	//when undoing a creation it's safe to decrease the newcount by one
