@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
  */
  
  
+#include "../include/fat16.h"
 #include "../include/fat32.h"
 
 /*****
@@ -29,6 +30,22 @@
 namespace GParted
 {
 
+const Glib::ustring ( & fat32::Change_UUID_Warning ) [] = fat16::Change_UUID_Warning ;
+
+const Glib::ustring fat32::get_custom_text( CUSTOM_TEXT ttype, int index )
+{
+	int i ;
+	switch ( ttype ) {
+		case CTEXT_CHANGE_UUID_WARNING :
+			for ( i = 0 ; i < index && Change_UUID_Warning[ i ] != "" ; i++ ) {
+				// Just iterate...
+			}
+			return Change_UUID_Warning [ i ] ;
+		default :
+			return FileSystem::get_custom_text( ttype, index ) ;
+	}
+}
+
 FS fat32::get_filesystem_support()
 {
 	FS fs ;
@@ -44,23 +61,29 @@ FS fat32::get_filesystem_support()
 		fs .read = GParted::FS::EXTERNAL ;
 	}
 
+	if ( ! Glib::find_program_in_path( "mdir" ) .empty() )
+		fs .read_uuid = FS::EXTERNAL ;
+
 	if ( ! Glib::find_program_in_path( "mlabel" ) .empty() ) {
 		fs .read_label = FS::EXTERNAL ;
 		fs .write_label = FS::EXTERNAL ;
+		fs .write_uuid = FS::EXTERNAL ;
 	}
 
-#ifndef HAVE_LIBPARTED_3_0_0_PLUS
+#ifdef HAVE_LIBPARTED_FS_RESIZE
 	//resizing of start and endpoint are provided by libparted
 	fs .grow = GParted::FS::LIBPARTED ;
 	fs .shrink = GParted::FS::LIBPARTED ;
-	fs .move = GParted::FS::LIBPARTED ;
-#else
+#endif
+#ifdef HAVE_LIBPARTED_3_0_0_PLUS
 	fs .move = FS::GPARTED ;
+#else
+	fs .move = GParted::FS::LIBPARTED ;
 #endif
 
 	fs .copy = GParted::FS::GPARTED ;
 	
-	fs .MIN = 32 * MEBIBYTE ; //smaller fs'es will cause windows scandisk to fail..
+	fs .MIN = 33 * MEBIBYTE ; //Smaller file systems will cause windows scandisk to fail.
 	
 	return fs ;
 }
@@ -154,6 +177,65 @@ bool fat32::write_label( const Partition & partition, OperationDetail & operatio
 	return ( exit_status == 0 );
 }
 
+void fat32::read_uuid( Partition & partition )
+{
+	//Create mtools config file
+	char fname[] = "/tmp/gparted-XXXXXXXX" ;
+	char dletter = 'H' ;
+	Glib::ustring err_msg = "" ;
+	err_msg = Utils::create_mtoolsrc_file( fname, dletter, partition.get_path() ) ;
+	if( err_msg.length() != 0 )
+		partition .messages .push_back( err_msg );
+
+	Glib::ustring cmd = String::ucompose( "export MTOOLSRC=%1 && mdir -f %2:", fname, dletter ) ;
+
+	if ( ! Utils::execute_command( cmd, output, error, true ) )
+	{
+		partition .uuid = Utils::regexp_label( output, "Volume Serial Number is[[:blank:]]([^[:space:]]+)" ) ;
+		if ( partition .uuid == "0000-0000" )
+			partition .uuid .clear() ;
+	}
+	else
+	{
+		if ( ! output .empty() )
+			partition .messages .push_back( output ) ;
+
+		if ( ! error .empty() )
+			partition .messages .push_back( error ) ;
+	}
+
+	err_msg = Utils::delete_mtoolsrc_file( fname );
+}
+
+
+bool fat32::write_uuid( const Partition & partition, OperationDetail & operationdetail )
+{
+	//Create mtools config file
+	char fname[] = "/tmp/gparted-XXXXXXXX" ;
+	char dletter = 'H' ;
+	Glib::ustring err_msg = "" ;
+	err_msg = Utils::create_mtoolsrc_file( fname, dletter, partition.get_path() ) ;
+
+	// Wait some time - 'random' UUIDs turn out identical if generated in quick succession...
+	sleep(1);
+	Glib::ustring cmd = String::ucompose( "export MTOOLSRC=%1 && mlabel -s -n %2:", fname, dletter ) ;
+
+	operationdetail .add_child( OperationDetail( cmd, STATUS_NONE, FONT_BOLD_ITALIC ) ) ;
+
+	int exit_status = Utils::execute_command( cmd, output, error ) ;
+
+	if ( ! output .empty() )
+		operationdetail .get_last_child() .add_child( OperationDetail( output, STATUS_NONE, FONT_ITALIC ) ) ;
+
+	if ( ! error .empty() )
+		operationdetail .get_last_child() .add_child( OperationDetail( error, STATUS_NONE, FONT_ITALIC ) ) ;
+
+	//Delete mtools config file
+	err_msg = Utils::delete_mtoolsrc_file( fname );
+
+	return ( exit_status == 0 );
+}
+
 bool fat32::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	return ! execute_command( "mkdosfs -F32 -v -n \"" + Utils::fat_compliant_label( new_partition .label ) + "\" " + new_partition .get_path(), operationdetail ) ;
