@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011, 2012 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,9 +28,9 @@ FS hfsplus::get_filesystem_support()
 	
 	fs .filesystem = GParted::FS_HFSPLUS ;
 
-#ifndef HAVE_LIBPARTED_3_0_0_PLUS
-	fs .read = GParted::FS::LIBPARTED ; 
-	fs .shrink = GParted::FS::LIBPARTED ; 
+#ifdef HAVE_LIBPARTED_FS_RESIZE
+	fs .read = GParted::FS::LIBPARTED ;
+	fs .shrink = GParted::FS::LIBPARTED ;
 #endif
 
 	if ( ! Glib::find_program_in_path( "mkfs.hfsplus" ) .empty() )
@@ -76,6 +76,15 @@ bool hfsplus::write_label( const Partition & partition, OperationDetail & operat
 	return true ;
 }
 
+void hfsplus::read_uuid( Partition & partition )
+{
+}
+
+bool hfsplus::write_uuid( const Partition & partition, OperationDetail & operationdetail )
+{
+	return true ;
+}
+
 bool hfsplus::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	Glib::ustring cmd = "";
