@@ -22,6 +22,39 @@
 namespace GParted
 {
 
+const Glib::ustring ntfs::Change_UUID_Warning [] =
+	{ _( "Changing the UUID might invalidate the Windows Product Activation (WPA) key."
+	   )
+	, _( "On FAT and NTFS file systems, the"
+	     " Volume Serial Number is used as the UUID."
+	     " Changing the Volume Serial Number on the Windows system"
+	     " partition, normally C:, might invalidate the WPA key."
+	     " An invalid WPA key will prevent login until you reactivate Windows."
+	   )
+	, _( "In an attempt to avoid invalidating the WPA key, on"
+	     " NTFS file systems only half of the UUID is set to a"
+	     " new random value."
+	   )
+	, _( "Changing the UUID on external storage media and non-system partitions"
+	     " is usually safe, but guarantees cannot be given."
+	   )
+	,    ""
+	} ;
+
+const Glib::ustring ntfs::get_custom_text( CUSTOM_TEXT ttype, int index )
+{
+	int i ;
+	switch ( ttype ) {
+		case CTEXT_CHANGE_UUID_WARNING :
+			for ( i = 0 ; i < index && Change_UUID_Warning[ i ] != "" ; i++ ) {
+				// Just iterate...
+			}
+			return Change_UUID_Warning [ i ] ;
+		default :
+			return FileSystem::get_custom_text( ttype, index ) ;
+	}
+}
+
 FS ntfs::get_filesystem_support()
 {
 	FS fs ;
@@ -34,8 +67,21 @@ FS ntfs::get_filesystem_support()
 	}
 
 	if ( ! Glib::find_program_in_path( "ntfslabel" ) .empty() ) {
+		Glib::ustring version ;
+
 		fs .read_label = FS::EXTERNAL ;
 		fs .write_label = FS::EXTERNAL ;
+
+		//Not all versions of ntfslabel support setting the Volume Serial Number
+		//The advanced (AR) release does as of the first 2012 release
+		//The stable release does not have it yet, at the time of this writing
+		//So: check for the presence of the command-line option.
+
+		//ntfslabel --help exits with non-zero error code (1)
+		Utils::execute_command( "ntfslabel --help ", output, error, false ) ;
+
+		if ( ! ( version = Utils::regexp_label( output, "--new-serial[[:blank:]]" ) ) .empty() )
+			fs .write_uuid = FS::EXTERNAL ;
 	}
 
 	if ( ! Glib::find_program_in_path( "mkntfs" ) .empty() )
@@ -104,6 +150,20 @@ bool ntfs::write_label( const Partition & partition, OperationDetail & operation
 	return ! execute_command( "ntfslabel --force " + partition .get_path() + " \"" + partition .label + "\"", operationdetail ) ;
 }
 
+void ntfs::read_uuid( Partition & partition )
+{
+}
+
+bool ntfs::write_uuid( const Partition & partition, OperationDetail & operationdetail )
+{
+	if ( partition .uuid == UUID_RANDOM_NTFS_HALF )
+		return ! execute_command( "ntfslabel --new-half-serial " + partition .get_path(), operationdetail ) ;
+	else
+		return ! execute_command( "ntfslabel --new-serial " + partition .get_path(), operationdetail ) ;
+
+	return true ;
+}
+
 bool ntfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	return ! execute_command( "mkntfs -Q -v -L \"" + new_partition .label + "\" " + new_partition .get_path(), operationdetail ) ;
